from .english import EnglishProperNounFilter
from .japanese import JapaneseProperNounFilter

# isort: unique-list
__all__ = ["EnglishProperNounFilter", "JapaneseProperNounFilter"]
